@@ -3,7 +3,7 @@ package Class::MakeMethods::Emulator::Inheritable;
 use strict;
 
 use Class::MakeMethods::Template::ClassInherit;
-use Class::MakeMethods::Utility::TakeName qw( namespace_capture namespace_release );
+use Class::MakeMethods::Emulator qw( namespace_capture namespace_release );
 
 my $emulation_target = 'Class::Data::Inheritable';
 
@@ -18,6 +18,8 @@ sub import {
   $mm_class->SUPER::import( @_ );
 }
 
+########################################################################
+
 sub mk_classdata {
   my $declaredclass = shift;
   my $attribute = shift;
@@ -31,6 +33,8 @@ sub mk_classdata {
   }
 }
 
+########################################################################
+
 1;
 
 __END__
@@ -144,42 +148,15 @@ no longer effect Raygun.
 
 =head1 SEE ALSO
 
+See L<Class::MakeMethods> for general information about this distribution. 
+
+See L<Class::MakeMethods::Emulator> for more about this family of subclasses.
+
 See L<Class::Data::Inheritable> for documentation of the original module.
 
 See L<perltootc> for a discussion of class data in Perl.
 
 See L<Class::MakeMethods::Standard::Inheritable> and L<Class::MakeMethods::Template::ClassInherit> for inheritable data methods. 
 
-See L<Class::MakeMethods> for an overview of the method-generation
-framework this is based on.
-
-See L<Class::MakeMethods::Guide> for a getting-started guide,
-annotated examples of usage, and a listing of the method generation
-classes included in this distribution.
-
-See L<Class::MakeMethods::ReadMe> for distribution, installation,
-version and support information.
-
-
-=head1 AUTHORS
-
-Developed by:
-
-  M. Simon Cavalletto, Evolution Online Systems, simonm@evolution.com
-
-Based on Class::Data::Inheritable, developed by:
-
-  Damian Conway and Michael G Schwern
-
-
-=head1 LICENSE
-
-Copyright (c) 2001 Evolution Online Systems, Inc.
-
-Portions Copyright (c) 2000, Damian Conway and Michael G Schwern.
-
-This module is free software. It may be used, redistributed and/or
-modified under the same terms as Perl.
-
 =cut
 
