@@ -3,6 +3,8 @@ package Class::MakeMethods::Emulator::MethodMaker;
 use Class::MakeMethods '-isasubclass';
 require Class::MakeMethods::Emulator;
 
+$VERSION = 1.03;
+
 use strict;
 
 =head1 NAME
@@ -47,8 +49,8 @@ Full compatibility is maintained with version 1.03; some of the
 changes in versions 1.04 through 1.10 are not yet included.
 
 The test suite from Class::MethodMaker version 1.10 is included
-with this package, in the t/8-methodmaker/ directory. The unsupported
-tests are in t/8-methodmaker/1.10-new-unsupported/.
+with this package, in the t-mm/ directory. The unsupported
+tests have names ending in ".todo".
 
 The tests are unchanged from those in the Class::MethodMaker
 distribution, except for the substitution of
