@@ -1,27 +1,31 @@
 package Class::MakeMethods::Emulator::Singleton;
 
 use strict;
-require Class::MakeMethods::Utility::TakeName;
+require Class::MakeMethods::Emulator;
 
 my $emulation_target = 'Class::Singleton';
 
 sub import {
   my $mm_class = shift;
   if ( scalar @_ and $_[0] =~ /^-take_namespace/ and shift) {
-    Class::MakeMethods::Utility::TakeName::namespace_capture(__PACKAGE__, $emulation_target);
+    Class::MakeMethods::Emulator::namespace_capture(__PACKAGE__, $emulation_target);
   } elsif ( scalar @_ and $_[0] =~ /^-release_namespace/ and shift) {
-    Class::MakeMethods::Utility::TakeName::namespace_release(__PACKAGE__, $emulation_target);
+    Class::MakeMethods::Emulator::namespace_release(__PACKAGE__, $emulation_target);
   }
   # The fallback should really be to NEXT::import.
   $mm_class->SUPER::import( @_ );
 }
 
+########################################################################
+
 use Class::MakeMethods (
   'Template::Hash:new --with_values' => '_new_instance',
   'Template::ClassVar:instance --get_init' => [ 'instance', 
 			{new_method=>'_new_instance', variable=>'_instance'} ]
 );
 
+########################################################################
+
 1;
 
 __END__
@@ -67,6 +71,10 @@ implement whatever specific functionality is required.
 
 =head1 SEE ALSO
 
+See L<Class::MakeMethods> for general information about this distribution. 
+
+See L<Class::MakeMethods::Emulator> for more about this family of subclasses.
+
 See L<Class::Singleton> for documentation of the original module.
 
 For a description and discussion of the Singleton class, see 
@@ -74,33 +82,4 @@ For a description and discussion of the Singleton class, see
 
 See L<Class::MakeMethods::Hash/new> and L<Class::MakeMethods::ClassVar/instance> for documentation of the created methods.
 
-See L<Class::MakeMethods> for an overview of the method-generation
-framework this is based on.
-
-See L<Class::MakeMethods::Guide> for a getting-started guide,
-annotated examples of usage, and a listing of the method generation
-classes included in this distribution.
-
-See L<Class::MakeMethods::ReadMe> for distribution, installation,
-version and support information.
-
-
-=head1 LICENSE
-
-This module is free software. It may be used, redistributed and/or
-modified under the same terms as Perl.
-
-Copyright (c) 2001 Evolution Online Systems, Inc.
-
-Portions Copyright (C) 1998 Canon Research Centre Europe Ltd. 
-
-Developed by:
-
-  M. Simon Cavalletto, Evolution Online Systems, simonm@evolution.com
-
-Based on Class::Singleton, developed by:
-
-  Andy Wardley, abw@cre.canon.co.uk
-
 =cut
-
