@@ -6,19 +6,12 @@ require Class::MakeMethods::Template::Array;
 sub generic {
   {
     '-import' => { 'Template::Struct:generic' => '*' },
-  }
-}
-
-sub new {
-  { 
-    '-import' => { 
-      'Template::PsuedoHash:generic' => '*',
-      'Template::Generic:new' => '*',
-    },
     'code_expr' => {
       _EMPTY_NEW_INSTANCE_ => 'bless [\%{"$class\::FIELDS"], _SELF_CLASS_',
     },
   }
 }
 
+### This package hasn't been completed yet
+
 1;
